==> simpla-5.x-1.2.tar.gz: simpla/page.tpl.php <==
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" lang="<?php print $language ?>" xml:lang="<?php print $language ?>">

<head>
  <title><?php print $head_title ?></title>
  <?php print $head ?>
  <?php print $styles ?>
  <?php print $scripts ?>
  <script type="text/javascript"><?php /* Needed to avoid Flash of Unstyle Content in IE */ ?> </script>

<!--[if IE]>
<style type="text/css"> 
/* place css fixes for all versions of IE in this conditional comment */
.twoColElsRtHdr #sidebar1 { padding-top: 30px; }
.twoColElsRtHdr #mainContent { zoom: 1; padding-top: 15px; }
/* the above proprietary zoom property gives IE the hasLayout it needs to avoid several bugs */
</style>
<![endif]-->
</head>

<body class="bd">
	<div id="header"><?php if ($site_name) { ?><h1 class='site-name'><a href="<?php print $base_path ?>" title="<?php print t('Home') ?>"><?php print $site_name ?></a></h1><?php } ?></div>
	<div id="menu"><?php if (isset($primary_links)) { ?><?php print theme('links', $primary_links, array('class' =>'links', 'id' => 'navlist')) ?><?php } ?></div>
	<div class="topShadow"></div>

<div id="container" class="clear-block">

	<div id="contentArea">
		

	<?php if($breadcrumb) { ?>
		<div id="breadcrumb">
			<div class="wrapper">
			<?php print $breadcrumb; ?>
			</div>
		</div>
	<?php } ?>
	<?php if ($sidebar_left) { ?>
		<div id="sidebarLeft">
			<?php print $sidebar_left ?>
		</div>
	<?php } ?>		
	<?php if ($sidebar_right) { ?>
		<div id="sidebarRight">
			<?php print $sidebar_right ?>
		</div>
	<?php } ?>
	<div id="<?php print phptemplate_contentClass($sidebar_left,$sidebar_right); ?>" class="">

        <h1 id="title"><?php print $title ?></h1>

        <div class="tabs"><?php print $tabs ?></div>
        <?php print $help ?>
        <?php print $messages ?>
        <?php print $content ?>
        <br class="clearfloat" />
	</div>
	<br class="clearfloat" />

	<div id="footer">
		<div class="wrapper">
	<?php
		if (isset($secondary_links)) { 
			print theme('links', $secondary_links, array('class' =>'links', 'id' => 'subnavlist'));
		}
		if (isset($footer_message) || isset ($feed_icons)) {
			echo "<p>";
			if(isset($footer_message)) echo "{$footer_message}";
			if(isset($feed_icons)) echo "{$feed_icons}";
			echo "</p>";
		} 
	?>
  		</div>
	</div>
</div>
<?php print $closure ?>
</body>
</html>

==> simpla-5.x-1.4.tar.gz: simpla/page.tpl.php <==
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" lang="<?php print $language ?>" xml:lang="<?php print $language ?>">

<head>
  <title><?php print $head_title ?></title>
  <?php print $head ?>
  <?php print $styles ?>
  <?php print $scripts ?>
  <script type="text/javascript"><?php /* Needed to avoid Flash of Unstyle Content in IE */ ?> </script>

<!--[if IE]>
<style type="text/css"> 
/* place css fixes for all versions of IE in this conditional comment */
.twoColElsRtHdr #sidebar1 { padding-top: 30px; }
.twoColElsRtHdr #mainContent { zoom: 1; padding-top: 15px; }
/* the above proprietary zoom property gives IE the hasLayout it needs to avoid several bugs */
</style>
<![endif]-->
</head>

<body class="bd">
	<div id="header"><?php if ($site_name) { ?><h1 class='site-name'><a href="<?php print $base_path ?>" title="<?php print t('Home') ?>"><?php print $site_name ?></a></h1><?php } ?></div>
	<div id="menu"><?php if (isset($primary_links)) { ?><?php print theme('links', $primary_links, array('class' =>'links', 'id' => 'primary_links')) ?><?php } ?></div>
	<?php if($breadcrumb) { ?>
		<div id="breadcrumb">
			<div class="wrapper">
			<?php print $breadcrumb; ?>
			</div>
		</div>
	<?php } ?>
	<div class="topShadow"></div>

<div id="container" class="clear-block">

	<div id="contentArea">
		


	<?php if ($sidebar_left) { ?>
		<div id="sidebarLeft">
			<?php print $sidebar_left ?>
		</div>
	<?php } ?>		
	<?php if ($sidebar_right) { ?>
		<div id="sidebarRight">
			<?php print $sidebar_right ?>
		</div>
	<?php } ?>
	<div id="<?php print phptemplate_contentClass($sidebar_left,$sidebar_right); ?>" class="">

        <h1 id="title"><?php print $title ?></h1>

        <div class="tabs"><?php print $tabs ?></div>
        <?php print $help ?>
        <?php print $messages ?>
        <?php print $content ?>
        <br class="clearfloat" />
	</div>
	<br class="clearfloat" />

	<div id="footer">
		<div class="wrapper">
	<?php
		if (isset($secondary_links)) { 
			print theme('links', $secondary_links, array('class' =>'links', 'id' => 'subnavlist'));
		}
		if (isset($footer_message) || isset ($feed_icons)) {
			echo "<p>";
			if(isset($footer_message)) echo "{$footer_message}";
			if(isset($feed_icons)) echo "{$feed_icons}";
			echo "</p>";
		} 
	?>
  		</div>
	</div>
</div>
<?php print $closure ?>
</body>
</html>
